@@ -169,7 +169,7 @@
   "style-src-elem 'self' 'unsafe-inline'; "  \
   "style-src 'self' 'unsafe-inline'; "       \
   "font-src 'self';"                         \
-  "img-src 'self' blob:;"
+  "img-src 'self' blob: data:;"
 
 /**
  * @brief Default "max-age" for HTTP header "Strict-Transport-Security"
@@ -427,7 +427,7 @@ params_append_mhd (params_t *params, const char *name, const char *filename,
       || (strcmp (name, "group_ids:") == 0)
       || (strcmp (name, "report_format_ids:") == 0)
       || (strcmp (name, "id_list:") == 0)
-      || (strcmp (name, "resource_ids:") == 0))
+      || (strcmp (name, "resource_ids:") == 0) || (strcmp (name, "kdcs:") == 0))
     {
       param_t *param;
       gchar *index_str;
@@ -812,6 +812,7 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
     }
   ELSE (bulk_delete)
   ELSE (bulk_export)
+  ELSE (change_password)
   ELSE (clone)
   ELSE (create_alert)
   ELSE (create_asset)
@@ -822,6 +823,9 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (create_group)
   ELSE (create_host)
   ELSE (create_note)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (create_oci_image_target)
+#endif
   ELSE (create_override)
   ELSE (create_permission)
   ELSE (create_permissions)
@@ -838,6 +842,10 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (create_tls_certificate)
   ELSE (create_user)
   ELSE (create_role)
+#if ENABLE_AGENTS
+  ELSE (create_agent_group)
+  ELSE (delete_agent_group)
+#endif
   ELSE (delete_asset)
   ELSE (delete_alert)
   ELSE (delete_config)
@@ -846,6 +854,9 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (delete_from_trash)
   ELSE (delete_group)
   ELSE (delete_note)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (delete_oci_image_target)
+#endif
   ELSE (delete_override)
   ELSE (delete_permission)
   ELSE (delete_port_list)
@@ -872,6 +883,9 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (restore)
   ELSE (resume_task)
   ELSE (run_wizard)
+#if ENABLE_AGENTS
+  ELSE (save_agent_group)
+#endif
   ELSE (save_alert)
   ELSE (save_asset)
   ELSE (save_auth)
@@ -889,6 +903,9 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   }
   ELSE (save_license)
   ELSE (save_note)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (save_oci_image_target)
+#endif
   ELSE (save_override)
   ELSE (save_permission)
   ELSE (save_port_list)
@@ -1489,6 +1506,10 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (export_groups)
   ELSE (export_note)
   ELSE (export_notes)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (export_oci_image_target)
+  ELSE (export_oci_image_targets)
+#endif
   ELSE (export_override)
   ELSE (export_overrides)
   ELSE (export_permission)
@@ -1516,6 +1537,17 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (export_tasks)
   ELSE (export_user)
   ELSE (export_users)
+#if ENABLE_AGENTS
+  ELSE (get_agent)
+  ELSE (get_agents)
+  ELSE (get_agent_group)
+  ELSE (get_agent_groups)
+  ELSE (get_agent_installers)
+  ELSE (get_agent_installer)
+  ELSE (get_agent_installer_file)
+  ELSE (save_agent_list)
+  ELSE (delete_agent_list)
+#endif
   ELSE (get_asset)
   ELSE (get_assets)
 
@@ -1572,6 +1604,10 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (get_note)
   ELSE (get_notes)
   ELSE (get_nvt_families)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (get_oci_image_target)
+  ELSE (get_oci_image_targets)
+#endif
   ELSE (get_override)
   ELSE (get_overrides)
   ELSE (get_permission)
@@ -1613,6 +1649,9 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (get_trash_filters)
   ELSE (get_trash_groups)
   ELSE (get_trash_notes)
+#if ENABLE_CONTAINER_SCANNING
+  ELSE (get_trash_oci_image_targets)
+#endif
   ELSE (get_trash_overrides)
   ELSE (get_trash_permissions)
   ELSE (get_trash_port_lists)
