@@ -694,12 +694,26 @@ get_trash_tags_gmp (gvm_connection_t *, credentials_t *, params_t *params,
 char *
 get_trash_targets_gmp (gvm_connection_t *, credentials_t *, params_t *params,
                        cmd_response_data_t *);
+
+#if ENABLE_CONTAINER_SCANNING
+char *
+get_trash_oci_image_targets_gmp (gvm_connection_t *, credentials_t *,
+                                 params_t *params, cmd_response_data_t *);
+#endif
+
 char *
 get_trash_tasks_gmp (gvm_connection_t *, credentials_t *, params_t *params,
                      cmd_response_data_t *);
 char *
 get_trash_tickets_gmp (gvm_connection_t *, credentials_t *, params_t *params,
                        cmd_response_data_t *);
+
+#if ENABLE_CONTAINER_SCANNING
+char *
+get_trash_oci_image_targets (gvm_connection_t *, credentials_t *,
+                             params_t *params, cmd_response_data_t *);
+#endif
+
 char *
 restore_gmp (gvm_connection_t *, credentials_t *, params_t *,
              cmd_response_data_t *);
@@ -805,6 +819,79 @@ char *
 get_capabilities_gmp (gvm_connection_t *, credentials_t *, params_t *,
                       cmd_response_data_t *);
 
+#if ENABLE_AGENTS
+char *
+get_agent_installers_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                          cmd_response_data_t *);
+
+char *
+get_agent_installer_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                         cmd_response_data_t *);
+
+char *
+get_agent_installer_file_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                              cmd_response_data_t *);
+
+char *
+get_agent_gmp (gvm_connection_t *, credentials_t *, params_t *,
+               cmd_response_data_t *);
+
+char *
+get_agents_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                cmd_response_data_t *);
+
+char *
+save_agent_list_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                     cmd_response_data_t *);
+
+char *
+delete_agent_list_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                       cmd_response_data_t *);
+char *
+get_agent_groups_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                      cmd_response_data_t *);
+
+char *
+get_agent_group_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                     cmd_response_data_t *);
+
+char *
+create_agent_group_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                        cmd_response_data_t *);
+
+char *
+save_agent_group_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                      cmd_response_data_t *);
+
+char *
+delete_agent_group_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                        cmd_response_data_t *);
+#endif
+
+#if ENABLE_CONTAINER_SCANNING
+char *
+get_oci_image_target_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                          cmd_response_data_t *);
+char *
+get_oci_image_targets_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                           cmd_response_data_t *);
+char *
+export_oci_image_targets_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                              cmd_response_data_t *);
+char *
+export_oci_image_target_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                             cmd_response_data_t *);
+char *
+create_oci_image_target_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                             cmd_response_data_t *);
+char *
+delete_oci_image_target_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                             cmd_response_data_t *);
+char *
+save_oci_image_target_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                           cmd_response_data_t *);
+#endif
+
 char *
 renew_session_gmp (gvm_connection_t *, credentials_t *, params_t *,
                    cmd_response_data_t *);
@@ -812,6 +899,10 @@ char *
 ping_gmp (gvm_connection_t *, credentials_t *, params_t *,
           cmd_response_data_t *);
 
+char *
+change_password_gmp (gvm_connection_t *, credentials_t *, params_t *,
+                     cmd_response_data_t *);
+
 int
 login (http_connection_t *con, params_t *params,
        cmd_response_data_t *response_data, const char *client_address);
