@@ -34,6 +34,7 @@ init_validator ()
   gvm_validator_add (validator, "cmd",
                      "^((bulk_delete)"
                      "|(bulk_export)"
+                     "|(change_password)"
                      "|(clone)"
                      "|(create_asset)"
                      "|(create_config)"
@@ -44,6 +45,7 @@ init_validator ()
                      "|(create_group)"
                      "|(create_host)"
                      "|(create_note)"
+                     "|(create_oci_image_target)"
                      "|(create_override)"
                      "|(create_permission)"
                      "|(create_permissions)"
@@ -61,7 +63,10 @@ init_validator ()
                      "|(create_ticket)"
                      "|(create_tls_certificate)"
                      "|(create_user)"
+                     "|(create_agent_group)"
                      "|(cvss_calculator)"
+                     "|(delete_agent_list)"
+                     "|(delete_agent_group)"
                      "|(delete_asset)"
                      "|(delete_config)"
                      "|(delete_credential)"
@@ -70,6 +75,7 @@ init_validator ()
                      "|(delete_from_trash)"
                      "|(delete_group)"
                      "|(delete_note)"
+                     "|(delete_oci_image_target)"
                      "|(delete_override)"
                      "|(delete_permission)"
                      "|(delete_port_list)"
@@ -109,6 +115,8 @@ init_validator ()
                      "|(export_groups)"
                      "|(export_note)"
                      "|(export_notes)"
+                     "|(export_oci_image_target)"
+                     "|(export_oci_image_targets)"
                      "|(export_omp_doc)"
                      "|(export_override)"
                      "|(export_overrides)"
@@ -137,6 +145,13 @@ init_validator ()
                      "|(export_tasks)"
                      "|(export_user)"
                      "|(export_users)"
+                     "|(get_agent)"
+                     "|(get_agents)"
+                     "|(get_agent_group)"
+                     "|(get_agent_groups)"
+                     "|(get_agent_installers)"
+                     "|(get_agent_installer)"
+                     "|(get_agent_installer_file)"
                      "|(get_aggregate)"
                      "|(get_alert)"
                      "|(get_alerts)"
@@ -159,6 +174,8 @@ init_validator ()
                      "|(get_note)"
                      "|(get_notes)"
                      "|(get_nvt_families)"
+                     "|(get_oci_image_target)"
+                     "|(get_oci_image_targets)"
                      "|(get_override)"
                      "|(get_overrides)"
                      "|(get_permission)"
@@ -200,6 +217,7 @@ init_validator ()
                      "|(get_trash_filters)"
                      "|(get_trash_groups)"
                      "|(get_trash_notes)"
+                     "|(get_trash_oci_image_targets)"
                      "|(get_trash_overrides)"
                      "|(get_trash_permissions)"
                      "|(get_trash_port_lists)"
@@ -228,6 +246,8 @@ init_validator ()
                      "|(resume_task)"
                      "|(run_wizard)"
                      "|(test_alert)"
+                     "|(save_agent_list)"
+                     "|(save_agent_group)"
                      "|(save_alert)"
                      "|(save_asset)"
                      "|(save_auth)"
@@ -242,6 +262,7 @@ init_validator ()
                      "|(save_license)"
                      "|(save_my_settings)"
                      "|(save_note)"
+                     "|(save_oci_image_target)"
                      "|(save_override)"
                      "|(save_permission)"
                      "|(save_port_list)"
@@ -418,6 +439,8 @@ init_validator ()
   gvm_validator_add (validator, "details", "^[0-1]$");
   /* Number is special cased in params_mhd_validate to remove the space. */
   gvm_validator_add (validator, "number", "^ *[0-9]+ *$");
+  gvm_validator_add (validator, "image_references",
+                     "^[-_[:alnum:],: \\./\\[\\]]+$");
   gvm_validator_add (validator, "optional_number", "^[0-9]*$");
   gvm_validator_add (validator, "oid", "^([0-9.]{1,80}|CVE-[-0-9]{1,14})$");
   gvm_validator_add (validator, "page", "^[_[:alnum:] ]+$");
@@ -441,6 +464,8 @@ init_validator ()
   gvm_validator_add (validator, "ca_pub", "(?s)^.*$");
   gvm_validator_add (validator, "which_cert", "^(default|existing|new)$");
   gvm_validator_add (validator, "kdc", "(?s)^.*$");
+  gvm_validator_alias (validator, "kdcs:name", "number");
+  gvm_validator_alias (validator, "kdcs:value", "kdc");
   gvm_validator_add (validator, "key_pub", "(?s)^.*$");
   gvm_validator_add (validator, "key_priv", "(?s)^.*$");
   gvm_validator_add (validator, "radiuskey", "^.*$");
@@ -470,11 +495,12 @@ init_validator ()
   gvm_validator_add (validator, "port_range_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (
     validator, "resource_type",
-    "^(alert|asset|audit_report|audit|cert_bund_adv|config|cpe|credential|cve|"
-    "dfn_cert_adv|filter|group|host|info|nvt|note|os|ovaldef|override|"
-    "permission|policy|port_list|report|report_config|report_format|result|"
-    "role|scanner|"
-    "schedule|tag|target|task|ticket|tls_certificate|user|vuln|)$");
+    "^(agent|alert|asset|audit_report|audit|cert_bund_adv|config|cpe|"
+    "credential|"
+    "cve|dfn_cert_adv|filter|group|host|info|nvt|note|oci_image_target|os|"
+    "ovaldef|override|permission|policy|port_list|report|report_config|"
+    "report_format|result|role|scanner|schedule|tag|target|task|ticket|"
+    "tls_certificate|user|vuln|)$");
   gvm_validator_add (validator, "resource_id", "^[[:alnum:]\\-_.:\\/~]*$");
   gvm_validator_add (validator, "resources_action", "^(|add|set|remove)$");
   gvm_validator_add (
@@ -497,6 +523,7 @@ init_validator ()
   gvm_validator_add (validator, "tag_value",
                      "^[\\-_@%[:alnum:], \\.\\/\\\\]*$");
   gvm_validator_add (validator, "target_id", "^[a-z0-9\\-]+$");
+  gvm_validator_add (validator, "oci_image_target_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "task_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "term", "^.*");
   gvm_validator_add (validator, "text", "^.*");
@@ -556,6 +583,14 @@ init_validator ()
 
   gvm_validator_alias (validator, "optional_task_id", "optional_id");
   gvm_validator_alias (validator, "add_tag", "boolean");
+  gvm_validator_alias (validator, "agent_installer_id", "id");
+  gvm_validator_alias (validator, "authorized", "boolean");
+  gvm_validator_alias (validator, "agent_ids:name", "number");
+  gvm_validator_alias (validator, "agent_ids:value", "id");
+  gvm_validator_alias (validator, "min_interval", "number");
+  gvm_validator_alias (validator, "heartbeat_interval", "number");
+  gvm_validator_alias (validator, "schedule", "number");
+  gvm_validator_alias (validator, "agent_group_id", "id");
   gvm_validator_alias (validator, "alert_id_2", "alert_id");
   gvm_validator_alias (validator, "alert_id_optional:name", "number");
   gvm_validator_alias (validator, "alert_id_optional:value",
